@@ -8,6 +8,7 @@
 #' @param year Numeric. Year of the data in YYYY format. Defaults to `2012`.
 #' @template simplified
 #' @template showProgress
+#' @template cache
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -18,7 +19,10 @@
 #' # Read Brazilian Legal Amazon
 #' a <- read_amazon(year = 2012)
 #'
-read_amazon <- function(year=2012, simplified=TRUE, showProgress=TRUE){
+read_amazon <- function(year = 2012,
+                        simplified = TRUE,
+                        showProgress = TRUE,
+                        cache = TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="amazonia_legal", year=year, simplified=simplified)
@@ -30,7 +34,9 @@ read_amazon <- function(year=2012, simplified=TRUE, showProgress=TRUE){
   file_url <- as.character(temp_meta$download_path)
 
   # download files
-  temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+  temp_sf <- download_gpkg(file_url = file_url,
+                           showProgress = showProgress,
+                           cache = cache)
 
   # check if download failed
   if (is.null(temp_sf)) { return(invisible(NULL)) }
