@@ -13,6 +13,7 @@
 #'             are separate data sets.
 #' @template simplified
 #' @template showProgress
+#' @template cache
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -35,7 +36,12 @@
 #' # Read all census tracts of the country at a given year
 #'   c <- read_census_tract(code_tract="all", year=2010)
 #'
-read_census_tract <- function(code_tract, year=2010, zone = "urban", simplified=TRUE, showProgress=TRUE){
+read_census_tract <- function(code_tract,
+                              year = 2010,
+                              zone = "urban",
+                              simplified = TRUE,
+                              showProgress = TRUE,
+                              cache = TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="census_tract", year=year, simplified=simplified)
@@ -70,7 +76,9 @@ read_census_tract <- function(code_tract, year=2010, zone = "urban", simplified=
       file_url <- as.character(temp_meta$download_path)
 
       # download files
-      temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+      temp_sf <- download_gpkg(file_url = file_url,
+                               showProgress = showProgress,
+                               cache = cache)
 
       # check if download failed
       if (is.null(temp_sf)) { return(invisible(NULL)) }
@@ -105,7 +113,9 @@ read_census_tract <- function(code_tract, year=2010, zone = "urban", simplified=
 
         }
       # download files
-      sf <- download_gpkg(file_url, progress_bar = showProgress)
+      sf <- download_gpkg(file_url = file_url,
+                               showProgress = showProgress,
+                               cache = cache)
 
       # check if download failed
       if (is.null(sf)) { return(invisible(NULL)) }
