@@ -8,6 +8,7 @@
 #' @param date Numeric. Date of the data in YYYYMM format. Defaults to `201909`.
 #' @template simplified
 #' @template showProgress
+#' @template cache
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -18,7 +19,10 @@
 #' # Read conservation_units
 #' b <- read_conservation_units(date = 201909)
 #'
-read_conservation_units <- function(date=201909, simplified=TRUE, showProgress=TRUE){
+read_conservation_units <- function(date = 201909,
+                                    simplified = TRUE,
+                                    showProgress = TRUE,
+                                    cache = TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="conservation_units", year=date, simplified=simplified)
@@ -27,7 +31,9 @@ read_conservation_units <- function(date=201909, simplified=TRUE, showProgress=T
   file_url <- as.character(temp_meta$download_path)
 
   # download files
-  temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+  temp_sf <- download_gpkg(file_url = file_url,
+                           showProgress = showProgress,
+                           cache = cache)
 
   # check if download failed
   if (is.null(temp_sf)) { return(invisible(NULL)) }
