@@ -6,6 +6,7 @@
 #' @param year Numeric. Year of the data in YYYY format. Defaults to `2010`.
 #' @template simplified
 #' @template showProgress
+#' @template cache
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -16,7 +17,10 @@
 #' # Read specific year
 #' br <- read_country(year = 2018)
 #'
-read_country <- function(year=2010, simplified=TRUE, showProgress=TRUE){
+read_country <- function(year = 2010,
+                         simplified = TRUE,
+                         showProgress = TRUE,
+                         cache = TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="country", year=year, simplified=simplified)
@@ -28,7 +32,9 @@ read_country <- function(year=2010, simplified=TRUE, showProgress=TRUE){
   file_url <- as.character(temp_meta$download_path)
 
   # download files
-  temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+  temp_sf <- download_gpkg(file_url = file_url,
+                           showProgress = showProgress,
+                           cache = cache)
 
   # check if download failed
   if (is.null(temp_sf)) { return(invisible(NULL)) }
