@@ -20,6 +20,7 @@
 #' @param date Numeric. Date of the data in YYYYMM format. Defaults to `202303`,
 #'        which was the latest data available by the time of this update.
 #' @template showProgress
+#' @template cache
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -30,7 +31,9 @@
 #' # Read all health facilities of the whole country
 #' h <- read_health_facilities( date = 202303)
 #'
-read_health_facilities <- function(date = 202303, showProgress = TRUE){
+read_health_facilities <- function(date = 202303,
+                                   showProgress = TRUE,
+                                   cache = TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="health_facilities", year=date, simplified=F)
@@ -39,7 +42,9 @@ read_health_facilities <- function(date = 202303, showProgress = TRUE){
     file_url <- as.character(temp_meta$download_path)
 
   # download files
-    temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+    temp_sf <- download_gpkg(file_url = file_url,
+                             showProgress = showProgress,
+                             cache = cache)
 
   # check if download failed
   if (is.null(temp_sf)) { return(invisible(NULL)) }
