@@ -12,6 +12,7 @@
 #'        immediate regions of the country.
 #' @template simplified
 #' @template showProgress
+#' @template cache
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -30,7 +31,11 @@
 #'   im <- read_immediate_region()
 #'   im <- read_immediate_region(code_immediate="all")
 #'
-read_immediate_region <- function(code_immediate="all", year=2019, simplified=TRUE, showProgress=TRUE){
+read_immediate_region <- function(code_immediate = "all",
+                                  year = 2019,
+                                  simplified = TRUE,
+                                  showProgress = TRUE,
+                                  cache = TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="immediate_regions", year=year, simplified=simplified)
@@ -42,28 +47,29 @@ read_immediate_region <- function(code_immediate="all", year=2019, simplified=TR
   file_url <- as.character(temp_meta$download_path)
 
   # download files
-  temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+  temp_sf <- download_gpkg(file_url = file_url,
+                           showProgress = showProgress,
+                           cache = cache)
 
   # check if download failed
   if (is.null(temp_sf)) { return(invisible(NULL)) }
 
+  ## FILTERS
+  y <- code_immediate
 
   # check code_immediate input
   if(code_immediate=="all"){
 
     # abbrev_state
   } else if(code_immediate %in% temp_sf$abbrev_state){
-    y <- code_immediate
     temp_sf <- subset(temp_sf, abbrev_state == y)
 
     # code_state
   } else if(code_immediate %in% temp_sf$code_state){
-    y <- code_immediate
     temp_sf <- subset(temp_sf, code_state == y)
 
     # code_immediate
   } else if(code_immediate %in% temp_sf$code_immediate){
-    y <- code_immediate
     temp_sf <- subset(temp_sf, code_immediate == y)
 
   } else {stop(paste0("Error: Invalid Value to argument 'code_immediate'",collapse = " "))}
