@@ -8,6 +8,7 @@
 #' @param year Numeric. Year of the data in YYYY format. Defaults to `2010`.
 #' @template simplified
 #' @template showProgress
+#' @template cache
 #'
 #' @return An `"sf" "data.frame"` object
 #'
@@ -18,7 +19,10 @@
 #' # Read neighborhoods of Brazilian municipalities
 #' n <- read_neighborhood(year=2010)
 #'
-read_neighborhood <- function(year=2010, simplified=TRUE, showProgress=TRUE){
+read_neighborhood <- function(year = 2010,
+                              simplified = TRUE,
+                              showProgress = TRUE,
+                              cache = TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="neighborhood", year=year, simplified=simplified)
@@ -27,7 +31,9 @@ read_neighborhood <- function(year=2010, simplified=TRUE, showProgress=TRUE){
   file_url <- as.character(temp_meta$download_path)
 
   # download files
-  temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+  temp_sf <- download_gpkg(file_url = file_url,
+                           showProgress = showProgress,
+                           cache = cache)
 
   # check if download failed
   if (is.null(temp_sf)) { return(invisible(NULL)) }
