@@ -12,6 +12,9 @@ test_that("read_meso_region", {
   expect_true(is(read_meso_region(code_meso="AC", year=2010), "sf"))
   # expect_true(is(read_meso_region(code_meso=11, year=2010), "sf"))
   expect_true(is(read_meso_region(code_meso="all", year=2010) , "sf"))
+  expect_true(is(read_meso_region(code_meso=12, year=2017) , "sf"))
+  expect_true(is(read_meso_region(code_meso="AM", year=2000) , "sf"))
+
 
   test_meso_code <-  read_meso_region(code_meso=1401, year=2010)
 
